use tui::layout::{Constraint, Direction, Layout, Rect};

/// helper function to create a centered rect using up certain percentage of the available rect `r`
pub fn centered_rect_percentage(percent_x: u16, percent_y: u16, r: Rect) -> Rect {
    let popup_layout = Layout::default()
        .direction(Direction::Vertical)
        .constraints(
            [
                Constraint::Percentage((100 - percent_y) / 2),
                Constraint::Percentage(percent_y),
                Constraint::Percentage((100 - percent_y) / 2),
            ]
            .as_ref(),
        )
        .split(r);

    Layout::default()
        .direction(Direction::Horizontal)
        .constraints(
            [
                Constraint::Percentage((100 - percent_x) / 2),
                Constraint::Percentage(percent_x),
                Constraint::Percentage((100 - percent_x) / 2),
            ]
            .as_ref(),
        )
        .split(popup_layout[1])[1]
}

/// helper function to create a centered rect using up certain container size
pub fn centered_rect_size(width: u16, height: u16, parent: &Rect) -> Rect {
    if parent.width < width || parent.height < height {
        return Rect {
            x: parent.x,
            y: parent.y,
            width: parent.width,
            height: parent.height,
        };
    }

    Rect {
        x: parent.x + (parent.width - width) / 2,
        y: parent.y + (parent.height - height) / 2,
        width,
        height,
    }
}

/// helper function to create a centered rect using up certain container size, only horizontally
pub fn centered_rect_size_horizontally(width: u16, parent: &Rect) -> Rect {
    if parent.width < width {
        return Rect {
            x: parent.x,
            y: parent.y,
            width: parent.width,
            height: parent.height,
        };
    }

    Rect {
        x: parent.x + (parent.width - width) / 2,
        y: parent.y,
        width,
        height: parent.height,
    }
}

/// Get coordinates to render centered text
pub fn centered_text(text: &str, container: &Rect) -> Rect {
    if text.len() > container.width as usize {
        return *container;
    }

    Rect {
        x: container.x + (container.width - text.len() as u16) / 2,
        y: container.y,
        height: 1,
        width: text.len() as u16,
    }
}
